# Generated by Django 3.2.16 on 2023-03-25 15:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("helpdesk", "0036_add_attachment_validator"),
    ]

    operations = [
        migrations.AlterField(
            model_name="queue",
            name="email_box_type",
            field=models.CharField(
                blank=True,
                choices=[
                    ("pop3", "POP 3"),
                    ("imap", "IMAP"),
                    ("oauth", "IMAP OAUTH"),
                    ("local", "Local Directory"),
                ],
                help_text="E-Mail server type for creating tickets automatically from a mailbox - both POP3 and IMAP are supported, as well as reading from a local directory.",
                max_length=5,
                null=True,
                verbose_name="E-Mail Box Type",
            ),
        ),
    ]
