# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-02-15 21:37
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("helpdesk", "0011_admin_related_improvements"),
    ]

    operations = [
        migrations.AddField(
            model_name="queue",
            name="default_owner",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="default_owner",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Default owner",
            ),
        ),
    ]
