# Generated by Django 2.2.13 on 2020-10-27 17:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("helpdesk", "0032_kbitem_enabled"),
    ]

    operations = [
        migrations.AddField(
            model_name="ticket",
            name="merged_to",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="merged_tickets",
                to="helpdesk.Ticket",
                verbose_name="merged to",
            ),
        ),
    ]
