/*	Font Old Standard
https://www.google.com/fonts/specimen/Old+Standard+TT
----------------------------------------------------- */
/*	VARIABLES
----------------------------------------------------- */
/* ICON PATH
================================================== */
/* TYPEFACE
================================================== */
/* COLOR SCHEME
================================================== */
/* UI COLOR
================================================== */
/* UI
================================================== */
/* Animation
================================================== */
/* GFX
================================================== */
@font-face {
  font-family: 'Old Standard TT';
  font-style: italic;
  font-weight: 400;
  src: local('Old Standard TT Italic'), local('OldStandardTT-Italic'), url(https://fonts.gstatic.com/s/oldstandardtt/v13/MwQsbh3o1vLImiwAVvYawgcf2eVer2q6bHY.ttf) format('truetype');
}
@font-face {
  font-family: 'Old Standard TT';
  font-style: normal;
  font-weight: 400;
  src: local('Old Standard TT Regular'), local('OldStandardTT-Regular'), url(https://fonts.gstatic.com/s/oldstandardtt/v13/MwQubh3o1vLImiwAVvYawgcf2eVeqlq9.ttf) format('truetype');
}
/*	Font Base
----------------------------------------------------- */
.tl-timeline {
  font-family: 'Old Standard TT', serif;
  font-weight: 400;
  font-size: 16px;
  line-height: 1.3em;
}
.tl-timeline h1,
.tl-timeline h2,
.tl-timeline h3,
.tl-timeline h4,
.tl-timeline h5,
.tl-timeline h6 {
  font-family: 'Old Standard TT', serif;
  text-transform: uppercase;
  font-weight: 400;
  font-size: 46px;
  line-height: 46px;
}
.tl-timeline h2.tl-headline-title {
  font-size: 52px;
  line-height: 52px;
}
.tl-timeline p {
  font-family: 'Old Standard TT', serif;
  font-size: 16px;
  line-height: 1.3em;
}
.tl-timeline ul {
  font-family: 'Old Standard TT', serif;
}
.tl-timeline .tl-media .tl-media-wikipedia h4 a,
.tl-timeline .tl-media h4,
.tl-timeline .tl-media h4 a {
  font-family: 'Old Standard TT', serif;
  font-weight: 400;
  font-size: 24px;
  line-height: 24px;
}
.tl-timeline .tl-caption,
.tl-timeline .tl-credit {
  font-family: 'Old Standard TT', serif;
}
.tl-timeline .vcard {
  font-family: 'Old Standard TT', serif !important;
  font-weight: normal !important;
}
.tl-timeline .tl-slidenav-next,
.tl-timeline .tl-slidenav-previous,
.tl-timeline .tl-message,
.tl-timeline .tl-timegroup-message {
  font-family: 'Old Standard TT', serif;
  font-weight: 400;
  text-transform: uppercase;
}
.tl-timeline .tl-slidenav-next .tl-slidenav-title,
.tl-timeline .tl-slidenav-previous .tl-slidenav-title,
.tl-timeline .tl-message .tl-slidenav-title,
.tl-timeline .tl-timegroup-message .tl-slidenav-title {
  line-height: 1.3em !important;
}
.tl-timeline .tl-headline-date,
.tl-timeline h3.tl-headline-date {
  font-family: 'Old Standard TT', serif !important;
  font-weight: normal !important;
  text-transform: uppercase !important;
}
.tl-timeline .tl-headline-date small,
.tl-timeline h3.tl-headline-date small {
  font-weight: normal !important;
}
.tl-timeline .tl-timenav-slider {
  font-family: 'Old Standard TT', serif;
  font-weight: 400;
}
.tl-timeline .tl-timenav-slider h2.tl-headline {
  font-family: 'Old Standard TT', serif;
  font-weight: 400;
  text-transform: uppercase;
}
.tl-timeline .tl-timenav-slider .tl-timeaxis {
  font-family: 'Old Standard TT', serif;
  font-weight: 400;
  text-transform: uppercase;
}
.tl-timeline .tl-menubar {
  font-family: 'Old Standard TT', serif;
}
.tl-timeline blockquote,
.tl-timeline blockquote p {
  font-family: 'Old Standard TT', serif;
  font-style: italic;
  font-weight: 400;
  line-height: 1.3;
}
input[type="text"].editor-headline {
  font-family: 'Old Standard TT', serif;
  text-transform: uppercase;
  font-weight: 400;
  font-size: 46px;
  line-height: 46px;
}
