<tr>
    {{ form.id }}
    <td title="Drag & Drop" class="text-right handle">
        <i class="fas fa-grip-vertical"></i>
        {{ form.position }}
        {{ form.position.errors }}
    </td>
    <td>
        {{ form.description }}
        {{ form.description.errors }}
    </td>
    <td>
        {{ form.DELETE }}
        {{ form.DELETE.errors }}
    </td>
</tr>