{% extends "helpdesk/base.html" %}{% load i18n %}

{% block helpdesk_title %}{% trans "Add Ticket as Dependency" %}{% endblock %}

{% block helpdesk_breadcrumb %}
<li class="breadcrumb-item">
    <a href="{% url 'helpdesk:list' %}">{% trans "Tickets" %}</a>
</li>
<li class="breadcrumb-item">
    <a href="{% url 'helpdesk:list' %}{{ depends_on.id }}/">{{ depends_on.queue.slug }}-{{ depends_on.id }}</a>
</li>
<li class="breadcrumb-item active">{% trans "Add Ticket as Dependency" %}</li>
{% endblock %}

{% block helpdesk_body %}{% blocktrans %}
<h2>Add Ticket as Dependency</h2>

<p>Ticket: {{ depends_on }} </p>

<p>Adding this ticket as dependency will stop you resolving the selected ticket until this ticket has been resolved or closed.</p>{% endblocktrans %}

<form method='post' action='./'>

<fieldset>
    <dl>{% for field in form %}
        <dt><label for='id_{{ field.name }}'>{{ field.label }}</label></dt>
        <dd>{{ field }}</dd>
        {% if field.errors %}<dd class='error'>{{ field.errors }}</dd>{% endif %}
        {% if field.help_text %}<dd class='form_help_text'>{{ field.help_text }}</dd>{% endif %}
    {% endfor %}</dl>
</fieldset>

<input class="btn btn-primary" type='submit' value='{% trans "Save Ticket Dependency" %}' />

{% csrf_token %}</form>

{% endblock %}
