{% extends "helpdesk/public_base.html" %}
{% load i18n %}

{% block helpdesk_title %}{% trans "Create Ticket" %}{% endblock %}

{% block helpdesk_breadcrumb %}
    <li class="breadcrumb-item">
        <a href="{% url 'helpdesk:home' %}">Public</a>
    </li>
    <li class="breadcrumb-item active">Create Ticket</li>
{% endblock %}

{% block helpdesk_body %}
    <div class="container">
        <div class="card card-register mx-auto mt-5">
            <div class="card-header">{% trans "Submit a Ticket" %}</div>
            <div class="card-body">
                {% include 'helpdesk/public_create_ticket_base.html' %}
            </div>
        </div>
    </div>
{% endblock %}

{% block helpdesk_js %}
    {{ form.media.js }}
{% endblock %}
