{% extends "helpdesk/public_base.html" %}{% load i18n %}

{% block helpdesk_title %}{% trans "Knowledgebase" %}{% endblock %}

{% block helpdesk_breadcrumb %}
<li class="breadcrumb-item">
    <a href="{% url 'helpdesk:kb_index' %}">{% trans "Knowledgebase" %}</a>
</li>
<li class="breadcrumb-item active">{% trans "Overview" %}</li>
{% endblock %}

{% block helpdesk_body %}
<h2>{% trans "Knowledgebase" %}</h2>

<p>{% trans "We have listed a number of Knowledgebase articles for your perusal in the following categories. Please check to see if any of these articles address your problem prior to opening a support ticket." %}</p>

{% for category in kb_categories %}
{% cycle 'one' 'two' 'three' as catnumperrow silent %}
{% if catnumperrow == 'one' %}<div class="card-deck">{% endif %}
<div class="card">
    <div class="card-header">
      <h5>{{ category.title }}</h5>
    </div>
    <div class="card-body">
        <p class="card-text">{{ category.description }}</p>
        <p class="card-text"><small class="text-muted"><a class="btn btn-primary" href='{{ category.get_absolute_url }}'>{% trans 'View articles' %} <i class="fa fa-share"></i></a></small></p>
    </div>
</div>
{% if catnumperrow == 'three' %}</div>{% endif %}
{% endfor %}

{% endblock %}
